@@ -7,7 +7,7 @@ from gatey_sdk.__version__ import __version__ as library_version
 # Default API server provider.
 # By default, this is API server provided from Florgon,
 # but user can override this with self-hosted provider.
-API_DEFAULT_SERVER_PROVIDER_URL = "https://api.florgon.space/gatey"
+API_DEFAULT_SERVER_PROVIDER_URL = "https://api.florgon.space/gatey/v1"
 
 # Expected version from the API server.
 API_DEFAULT_SERVER_EXPECTED_VERSION = "0.0.0"
